Sensei no Shiroi Uso - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Sensei no Shiroi Uso

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Sensei%20no%20Shiroi%20Uso/%E5%85%88%E7%94%9F%E3%81%AE%E7%99%BD%E3%81%84%E5%98%98.2024.WEBRip.Amazon.ja-jp%5Bsdh%5D.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Sensei%20no%20Shiroi%20Uso/%E5%85%88%E7%94%9F%E3%81%AE%E7%99%BD%E3%81%84%E5%98%98.WEBRip.Netflix.ja%5Bcc%5D.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | 先生の白い嘘.2024.WEBRip.Amazon.ja-jp[sdh].srt | 85.76 KiB | 27 Nov 2025 03:29:18
2 | 先生の白い嘘.WEBRip.Netflix.ja[cc].srt | 86.83 KiB | 21 Jan 2026 20:43:54

Nothing to show.

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Sensei%20no%20Shiroi%20Uso/%E5%85%88%E7%94%9F%E3%81%AE%E7%99%BD%E3%81%84%E5%98%98.2024.WEBRip.Amazon.ja-jp%5Bsdh%5D.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/drama_movie/Sensei%20no%20Shiroi%20Uso/%E5%85%88%E7%94%9F%E3%81%AE%E7%99%BD%E3%81%84%E5%98%98.WEBRip.Netflix.ja%5Bcc%5D.srt'

# | Name | Size | Last modified (UTC)
--- | --- | --- | ---
1 | 先生の白い嘘.2024.WEBRip.Amazon.ja-jp[sdh].srt | 85.76 KiB | 27 Nov 2025 03:29:18
2 | 先生の白い嘘.WEBRip.Netflix.ja[cc].srt | 86.83 KiB | 21 Jan 2026 20:43:54

Upload new files — Search MDL — Back to Index